#!/bin/bash
echo -e "Running Mobt Initialization Script\n"

makedir(){
#create directory structure for each application
echo -e "Creating /appl directory.\n"
mkdir -p /appl
echo -e "\nDone.\n"
}

# Move /home to new volume :
# Simple: create symlink /home -> /appl/home

chghome(){

lnktarget="/appl/home"
lnksource="/home"

echo -e "Move $lnksource to $lnktarget and creating softlink.\n"

# create symlink and also check for symlink

if [ ! -d "$lnktarget" ]; then
    mkdir -p $lnktarget
    echo -e "Creating symlink..."

    echo -e "Rsyncing..."
    rsync -avh --stats --progress $lnksource  /appl

    echo -e "Removing $lnksource..."
    rm -rf $lnksource
    echo -e "Linking $lnksource to $lnktarget..."
    ln -s $lnktarget $lnksource
    echo -e "\nDone."

else
  echo -e "Removing $lnksource..."
  rm -rf $lnksource
  echo -e "Linking $lnksource to $lnktarget..."
  ln -s $lnktarget $lnksource
  echo -e "\nDone."
fi
}

prepare_vol(){

echo -e "\nPrepare Volume.\n"

# if wait for the device to show up before running this
voldata_dev=$(find /dev/disk/by-id -maxdepth 1 -name "*virtio*" -print)

#Note: Might not work with full block devices
output=$(file -sL $voldata_dev | grep -c ext4)

if [ $output == "1" ]; then
    dev_ret=$(grep "${voldata_dev}" "/etc/fstab")
      if [ $? -eq 0 ]; then
          echo "uuid of block dev already exist in fstab"
      else
          echo -e "Making entries in /etc/fstab..."
          echo "${voldata_dev} /appl ext4 defaults 1 2" >> /etc/fstab
      fi
    echo "Mounting /appl..."
    mount /appl
    echo -e "\nDone.\n"

else

    echo "Making file system..."
    mkfs.ext4 $voldata_dev
    echo "Making entries in /etc/fstab..."
    echo "${voldata_dev} /appl ext4 defaults 1 2" >> /etc/fstab
    echo "Mounting /appl..."
    mount /appl
    echo -e "\nDone.\n"
fi
}

pre_config(){

echo -e "Starting pre-config.\n"
echo -e "Checking DNS in /etc/resolv.conf..."

val=$(grep $adm_domain_name "/etc/resolv.conf")
if [ $? -eq 0 ]; then
   echo "Internal dns already populated."
else
    echo -e "Adding entires into /etc/resolvconf/resolv.conf.d/tail and head files..."
    echo "domain $adm_domain_name" >> /etc/resolvconf/resolv.conf.d/tail
    echo "nameserver $adm_dns_nameserver_0" >> /etc/resolvconf/resolv.conf.d/head
    echo "nameserver $adm_dns_nameserver_1" >> /etc/resolvconf/resolv.conf.d/head

    #add the necessary MUAM servers to /etc/hosts
    echo -e "Adding MUAM entires into /etc/hosts file..."
    echo "$adm_muam_ip_0 $adm_muam_server0" >> /etc/hosts
    echo "$adm_muam_ip_1 $adm_muam_server1" >> /etc/hosts
fi

#get the hostname,FQDN & IP and add to /etc/hosts
hname=`hostname`
hfqdn=`hostname`.$adm_domain_name
#hip=`hostname -i`
hip=`ip addr show eth0 | grep -Po 'inet \K[\d.]+'`
# do ip address, reverse look to determine what to put in /etc/hosts
echo -e "Adding hostname, IP and FQDN to /etc/hosts..."
echo "$hip $hfqdn $hname"
echo "$hip $hfqdn $hname" >> /etc/hosts

echo -e "\nDone.\n"
}
install_uam(){

#install UAM
						
								 
uncompress /var/tmp/uam_extranet.tar.Z
							
tar xvf /var/tmp/uam_extranet.tar -C /
									
cd /usr/localcw/uam/ && ./install_uam.sh -l
#Recommended for ensuring server pushes all user configuration to the systems
/usr/localcw/uam/uam_auto.pl load
/usr/localcw/uam/uam_auto.pl role
/usr/localcw/uam/uam_auto.pl check
/usr/localcw/uam/uam_auto.pl sudo
/usr/localcw/uam/uam_auto.pl sshkey
/usr/localcw/uam/uam_auto.pl
}

install_allmids(){
#install IEDS
echo -e "Install allmids.\n"
cd /usr/localcw/bin
echo "Untaring allmid files..."
tar zxvf /var/tmp/*allmid* -C .
echo "Running allmid install script..."
./allmid.sh -N
hname=`hostname`
echo "Sending email to IEDS..."
mail -s "XML Inventory from $hname" iedsprd@ieds-data.it.att.com < /tmp/allmid.out
echo -e "\nDone.\n"
}

post_config(){
echo -e "Starting post-config.\n"

   echo "Copying allmid and UAM files to /var/tmp from backup URL..."
   wget -O /var/tmp/allmid.tar.gz $adm_http_allmid
   wget -O /var/tmp/uam_extranet.tar.Z  $adm_http_uam  
   echo -e "\nDone.\n"
   echo -e "\nInstalling UAM and allmids. \n"
   install_uam && install_allmids

				   
}

waitforvol(){
    wait_time=0
    until [[ -e /dev/disk/by-id ]] || [[ $wait_time -eq 4 ]]; do
    sleep $((wait_time++))
    done
    return $((wait_time))
}

#######################
######   MAIN  ########
#######################

    pre_config
    makedir
    rm /etc/resolv.conf
    ln -s /run/resolvconf/resolv.conf /etc/resolv.conf
    resolvconf -u
	
    echo -e "Checking if volume is available for preparation..."	
    waitforvol

      if [ $? -lt 4 ]; then
        prepare_vol
        chghome
      fi

    post_config && reboot
